@@ -125,9 +125,11 @@ class Models( ml_pipeline.ML_ParentClass.ML_ParentClass ):
         '''initialize the Dirs if they do not already exist '''
 
         for Dir in self.Dirs:
-            Dir.create()
+            if not Dir.exists():
+                Dir.create( override = True )
         for key in self.data_Dirs:
-            self.data_Dirs[ key ].create()
+            if not self.data_Dirs[ key ].exists():
+                self.data_Dirs[ key ].create( override = True )
 
     def _set_Paths( self ):
 
@@ -281,8 +283,8 @@ class Models( ml_pipeline.ML_ParentClass.ML_ParentClass ):
             ]
 
         for Dir_to_delete in Dirs_to_delete:
-            Dir_to_delete.remove( override = override ) #delete the folder and all contents
-            Dir_to_delete.create() #create the folder again
+            if Dir_to_delete.remove( override = override ): #delete the folder and all contents
+                Dir_to_delete.create( override = True ) #create the folder again if the deletion was successful
 
         print ('To properly save changes, exit the program')
 
